@@ -4,11 +4,11 @@
 tmdbsimple
 ~~~~~~~~~~
 
-*tmdbsimple* is a wrapper, written in Python, for The Movie Database (TMDb) 
-API v3.  By calling the functions available in *tmdbsimple* you can simplify 
-your code and easily access a vast amount of movie, tv, and cast data.  To find 
-out more about The Movie Database API, check out the overview page 
-http://www.themoviedb.org/documentation/api and documentation page 
+*tmdbsimple* is a wrapper, written in Python, for The Movie Database (TMDb)
+API v3.  By calling the functions available in *tmdbsimple* you can simplify
+your code and easily access a vast amount of movie, tv, and cast data.  To find
+out more about The Movie Database API, check out the overview page
+http://www.themoviedb.org/documentation/api and documentation page
 https://developers.themoviedb.org/3/getting-started
 https://www.themoviedb.org/documentation/api/status-codes
 
@@ -17,7 +17,7 @@ https://www.themoviedb.org/documentation/api/status-codes
 """
 
 __title__ = 'tmdbsimple'
-__version__ = '2.3.1'
+__version__ = '2.4.1'
 __author__ = 'Celia Oakley'
 __copyright__ = 'Copyright (c) 2013-2020 Celia Oakley'
 __license__ = 'GPLv3'
@@ -36,6 +36,18 @@ from .people import People, Credits, Jobs
 from .search import Search
 from .tv import TV, TV_Seasons, TV_Episodes, TV_Episode_Groups, TV_Changes, Networks
 
+__all__ = ['Account', 'Authentication', 'GuestSessions', 'Lists',
+           'APIKeyError',
+           'Changes',
+           'Configuration', 'Certifications', 'Timezones',
+           'Discover',
+           'Find', 'Trending',
+           'Genres',
+           'Movies', 'Collections', 'Companies', 'Keywords', 'Reviews',
+           'People', 'Credits', 'Jobs',
+           'Search',
+           'TV', 'TV_Seasons', 'TV_Episodes', 'TV_Episode_Groups', 'TV_Changes', 'Networks'
+           ]
 
 API_KEY = os.environ.get('TMDB_API_KEY', None)
 API_VERSION = '3'
