@@ -14,6 +14,7 @@ Created by Celia Oakley on 2013-10-31.
 
 from .base import TMDB
 
+
 class TV(TMDB):
     """
     TV functionality.
@@ -51,7 +52,10 @@ class TV(TMDB):
 
     def info(self, **kwargs):
         """
-        Get the primary information about a TV series by id.
+        Get the primary TV show details by id.
+
+        Supports append_to_response. Read more about this at
+        https://developers.themoviedb.org/3/getting-started/append-to-response.
 
         Args:
             language: (optional) ISO 639 code.
@@ -88,7 +92,7 @@ class TV(TMDB):
 
     def alternative_titles(self, **kwargs):
         """
-        Get the alternative titles for a specific tv id.
+        Returns all of the alternative titles for a TV show.
 
         Args:
             language: (optional) ISO 3166-1 code.
@@ -104,7 +108,8 @@ class TV(TMDB):
 
     def content_ratings(self, **kwargs):
         """
-        Get the content ratings for a TV Series.
+        Get the list of content ratings (certifications) that have been added
+        to a TV show.
 
         Args:
             language: (optional) ISO 639 code.
@@ -122,8 +127,7 @@ class TV(TMDB):
 
     def credits(self, **kwargs):
         """
-        Get the cast & crew information about a TV series. Just like the
-        website, we pull this information from the last season of the series.
+        Get the credits (cast and crew) that have been added to a TV show.
 
         Args:
             language: (optional) ISO 639 code.
@@ -142,6 +146,7 @@ class TV(TMDB):
     def episode_groups(self, **kwargs):
         """
         Get all of the episode groups that have been created for a TV show.
+        With a group ID you can call the get TV episode group details  method.
 
         Args:
             language: (optional) ISO 639 code.
@@ -157,7 +162,14 @@ class TV(TMDB):
 
     def external_ids(self, **kwargs):
         """
-        Get the external ids that we have stored for a TV series.
+        Get the external ids for a TV show. We currently support the following
+        external sources.
+
+        Media Databases: IMDb ID, TVDB ID, Freebase MID*, Freebase ID*, TVRage
+        ID*
+        Social IDs: Facebook, Instagram, Twitter
+
+        *Defunct or no longer available as a service.
 
         Args:
             language: (optional) ISO 639 code.
@@ -173,7 +185,13 @@ class TV(TMDB):
 
     def images(self, **kwargs):
         """
-        Get the images (posters and backdrops) for a TV series.
+        Get the images that belong to a TV show.
+
+        Querying images with a language parameter will filter the results. If
+        you want to include a fallback language (especially useful for
+        backdrops) you can use the include_image_language parameter. This
+        should be a comma seperated value like so:
+        include_image_language=en,null.
 
         Args:
             language: (optional) ISO 639 code.
@@ -191,7 +209,7 @@ class TV(TMDB):
 
     def keywords(self, **kwargs):
         """
-        Get the list of keywords related to a TV series.
+        Get the keywords that have been added to a TV show.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -204,7 +222,7 @@ class TV(TMDB):
 
     def recommendations(self, **kwargs):
         """
-        Get the recommendations for TV series for a specific TV series id.
+        Get the list of TV show recommendations for this item.
 
         Args:
             page: (optional) Minimum value of 1.  Expected value is an integer.
@@ -238,7 +256,8 @@ class TV(TMDB):
 
     def screened_theatrically(self, **kwargs):
         """
-        Get a list of seasons or episodes that have been screened in a film festival or theatre.
+        Get a list of seasons or episodes that have been screened in a film
+        festival or theatre.
 
         Args:
             page: (optional) Minimum value of 1.  Expected value is an integer.
@@ -255,7 +274,8 @@ class TV(TMDB):
 
     def similar(self, **kwargs):
         """
-        Get the similar TV series for a specific TV series id.
+        Get a list of similar TV shows. These items are assembled by looking at
+        keywords and genres.
 
         Args:
             page: (optional) Minimum value of 1.  Expected value is an integer.
@@ -273,8 +293,7 @@ class TV(TMDB):
 
     def translations(self, **kwargs):
         """
-        Get the list of translations that exist for a TV series. These
-        translations cascade down to the episode level.
+        Get a list of the translations that exist for a TV show.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -287,8 +306,7 @@ class TV(TMDB):
 
     def videos(self, **kwargs):
         """
-        Get the videos that have been added to a TV series (trailers, opening
-        credits, etc...).
+        Get the videos that have been added to a TV show.
 
         Args:
             language: (optional) ISO 639 code.
@@ -330,8 +348,8 @@ class TV(TMDB):
 
     def latest(self, **kwargs):
         """
-        Get the most newly created TV show. This is a live response
-        and will continuously change.
+        Get the most newly created TV show. This is a live response and will
+        continuously change.
 
         Args:
             language: (optional) ISO 639 code.
@@ -347,8 +365,12 @@ class TV(TMDB):
 
     def airing_today(self, **kwargs):
         """
-        Get the list of TV shows that air today. Without a specified timezone,
-        this query defaults to EST (Eastern Time UTC-05:00).
+        Get a list of TV shows that are airing today. This query is purely day
+        based as we do not currently support airing times.
+
+        You can specify a timezone to offset the day calculation. Without a
+        specified timezone, this query defaults to EST (Eastern Time
+        UTC-05:00).
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -366,9 +388,10 @@ class TV(TMDB):
 
     def on_the_air(self, **kwargs):
         """
-        Get the list of TV shows that are currently on the air. This query
-        looks for any TV show that has an episode with an air date in the
-        next 7 days.
+        Get a list of shows that are currently on the air.
+
+        This query looks for any TV show that has an episode with an air date
+        in the next 7 days.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -385,7 +408,8 @@ class TV(TMDB):
 
     def popular(self, **kwargs):
         """
-        Get the list of popular TV shows. This list refreshes every day.
+        Get a list of the current popular TV shows on TMDb. This list updates
+        daily.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -402,9 +426,7 @@ class TV(TMDB):
 
     def top_rated(self, **kwargs):
         """
-        Get the list of top rated TV shows. By default, this list will only
-        include TV shows that have 2 or more votes. This list refreshes every
-        day.
+        Get a list of the top rated TV shows on TMDb.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -443,7 +465,10 @@ class TV_Seasons(TMDB):
 
     def info(self, **kwargs):
         """
-        Get the primary information about a TV season by its season number.
+        Get the TV season details by id.
+
+        Supports append_to_response. Read more about this at
+        https://developers.themoviedb.org/3/getting-started/append-to-response.
 
         Args:
             language: (optional) ISO 639 code.
@@ -479,7 +504,7 @@ class TV_Seasons(TMDB):
 
     def credits(self, **kwargs):
         """
-        Get the cast & crew credits for a TV season by season number.
+        Get the credits for TV season.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -492,8 +517,12 @@ class TV_Seasons(TMDB):
 
     def external_ids(self, **kwargs):
         """
-        Get the external ids that we have stored for a TV season by season
-        number.
+        Get the external ids for a TV season. We currently support the
+        following external sources.
+
+        Media Databases: TVDB ID, Freebase MID*, Freebase ID*, TVRage ID*
+
+        *Defunct or no longer available as a service.
 
         Args:
             language: (optional) ISO 639 code.
@@ -509,8 +538,13 @@ class TV_Seasons(TMDB):
 
     def images(self, **kwargs):
         """
-        Get the images (posters) that we have stored for a TV season by season
-        number.
+        Get the images that belong to a TV season.
+
+        Querying images with a language parameter will filter the results. If
+        you want to include a fallback language (especially useful for
+        backdrops) you can use the include_image_language parameter. This
+        should be a comma seperated value like so:
+        include_image_language=en,null.
 
         Args:
             language: (optional) ISO 639 code.
@@ -528,8 +562,7 @@ class TV_Seasons(TMDB):
 
     def videos(self, **kwargs):
         """
-        Get the videos that have been added to a TV season (trailers, teasers,
-        etc...).
+        Get the videos that have been added to a TV season.
 
         Args:
             language: (optional) ISO 639 code.
@@ -570,8 +603,10 @@ class TV_Episodes(TMDB):
 
     def info(self, **kwargs):
         """
-        Get the primary information about a TV episode by combination of a
-        season and episode number.
+        Get the TV episode details by id.
+
+        Supports append_to_response. Read more about this at
+        https://developers.themoviedb.org/3/getting-started/append-to-response.
 
         Args:
             language: (optional) ISO 639 code.
@@ -589,7 +624,7 @@ class TV_Episodes(TMDB):
 
     def account_states(self, **kwargs):
         """
-        Get your rating for a episode.
+        Get your rating for an episode.
 
         Args:
             language: (optional) ISO 639 code.
@@ -607,7 +642,7 @@ class TV_Episodes(TMDB):
 
     def credits(self, **kwargs):
         """
-        Get the TV episode credits by combination of season and episode number.
+        Get the credits (cast, crew and guest stars) for a TV episode.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -620,8 +655,13 @@ class TV_Episodes(TMDB):
 
     def external_ids(self, **kwargs):
         """
-        Get the external ids for a TV episode by combination of a season and
-        episode number.
+        Get the external ids for a TV episode. We currently support the
+        following external sources.
+
+        External Sources: IMDb ID, TVDB ID, Freebase MID*, Freebase ID*, TVRage
+        ID*
+
+        *Defunct or no longer available as a service.
 
         Args:
             language: (optional) ISO 639 code.
@@ -638,9 +678,13 @@ class TV_Episodes(TMDB):
 
     def images(self, **kwargs):
         """
-        Get the images (episode stills) for a TV episode by combination of a
-        season and episode number. Since episode stills don't have a language,
-        this call will always return all images.
+        Get the images that belong to a TV episode.
+
+        Querying images with a language parameter will filter the results. If
+        you want to include a fallback language (especially useful for
+        backdrops) you can use the include_image_language parameter. This
+        should be a comma seperated value like so:
+        include_image_language=en,null.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -692,8 +736,7 @@ class TV_Episodes(TMDB):
 
     def videos(self, **kwargs):
         """
-        Get the videos that have been added to a TV episode (teasers, clips,
-        etc...).
+        Get the videos that have been added to a TV episode.
 
         Args:
             language: (optional) ISO 639 code.
@@ -725,14 +768,15 @@ class TV_Episode_Groups(TMDB):
 
     def info(self, **kwargs):
         """
-        Get the details of a TV episode group. Groups support 7 different types which are enumerated as the following:
+        Get the details of a TV episode group. Groups support 7 different types
+        which are enumerated as the following:
             1. Original air date
             2. Absolute
             3. DVD
             4. Digital
             5. Story arc
             6. Production
-            7. TV        
+            7. TV
 
         Args:
             language: (optional) ISO 639 code.
@@ -768,11 +812,16 @@ class TV_Changes(TMDB):
 
     def series(self, **kwargs):
         """
-        Get the changes for a specific series id.
+        Get the changes for a TV show. By default only the last 24 hours are returned.
 
-        Changes are grouped by key, and ordered by date in descending order.
-        By default, only the last 24 hours of changes are returned. The
-        maximum number of days that can be returned in a single request is 14.
+        You can query up to 14 days in a single query by using the start_date
+        and end_date query parameters.
+
+        TV show changes are different than movie changes in that there are some
+        edits on seasons and episodes that will create a change entry at the
+        show level. These can be found under the season and episode keys. These
+        keys will contain a series_id and episode_id. You can use the season
+        changes and episode changes methods to look these up individually.
 
         Args:
             start_date: (optional) Expected format is 'YYYY-MM-DD'.
@@ -790,11 +839,10 @@ class TV_Changes(TMDB):
 
     def season(self, **kwargs):
         """
-        Get the changes for a specific season id.
+        Get the changes for a TV season. By default only the last 24 hours are returned.
 
-        Changes are grouped by key, and ordered by date in descending order.
-        By default, only the last 24 hours of changes are returned. The
-        maximum number of days that can be returned in a single request is 14.
+        You can query up to 14 days in a single query by using the start_date
+        and end_date query parameters.
 
         Args:
             start_date: (optional) Expected format is 'YYYY-MM-DD'.
@@ -812,11 +860,10 @@ class TV_Changes(TMDB):
 
     def episode(self, **kwargs):
         """
-        Get the changes for a specific episode id.
+        Get the changes for a TV episode. By default only the last 24 hours are returned.
 
-        Changes are grouped by key, and ordered by date in descending order.
-        By default, only the last 24 hours of changes are returned. The
-        maximum number of days that can be returned in a single request is 14.
+        You can query up to 14 days in a single query by using the start_date
+        and end_date query parameters.
 
         Args:
             start_date: (optional) Expected format is 'YYYY-MM-DD'.
@@ -852,9 +899,7 @@ class Networks(TMDB):
 
     def info(self, **kwargs):
         """
-        This method is used to retrieve the basic information about a TV
-        network. You can use this ID to search for TV shows with the discover.
-        At this time we don't have much but this will be fleshed out over time.
+        Get the details of a network.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -884,6 +929,16 @@ class Networks(TMDB):
         """
         Get a TV network logos by id.
 
+        There are two image formats that are supported for networks, PNG's and
+        SVG's. You can see which type the original file is by looking at the
+        file_type field. We prefer SVG's as they are resolution independent and
+        as such, the width and height are only there to reflect the original
+        asset that was uploaded. An SVG can be scaled properly beyond those
+        dimensions if you call them as a PNG.
+
+        For more information about how SVG's and PNG's can be used, take a read
+        through https://developers.themoviedb.org/3/getting-started/images.
+
         Args:
 
         Returns:
